@@ -5,7 +5,7 @@
 # Collection of functions related to Google urls.
 #
 import re
-from ural.utils import safe_urlsplit, unquote
+from ural.utils import safe_urlsplit, unquote, urlpathsplit
 from ural.patterns import QUERY_VALUE_IN_URL_TEMPLATE
 
 AMP_QUERY_RE = re.compile(r'amp(_.+)=?', re.I)
@@ -13,6 +13,8 @@ AMP_SUFFIXES_RE = re.compile(r'(?:\.amp(?=\.html$)|\.amp/?$|(?<=/)amp/?$)', re.I
 
 URL_EXTRACT_RE = re.compile(QUERY_VALUE_IN_URL_TEMPLATE % r'url')
 
+DRIVE_TYPES = ['document', 'presentation', 'spreadsheets']
+
 
 def is_amp_url(url):
     splitted = safe_urlsplit(url)
@@ -57,3 +59,23 @@ def extract_url_from_google_link(url):
         return None
 
     return unquote(m.group(1))
+
+
+def extract_id_from_google_drive_url(url):
+    splitted = safe_urlsplit(url)
+
+    if 'docs.google.com' not in splitted.netloc:
+        return None
+
+    path = urlpathsplit(splitted.path)
+
+    if len(path) < 3:
+        return None
+
+    if path[0] not in DRIVE_TYPES:
+        return None
+
+    if path[1] != 'd':
+        return None
+
+    return path[2]
